@@ -1,15 +1,15 @@
-import os, sys
-sys.path.append(os.path.abspath('/root/pydata/tpexe/tpexe/action'))
+import os
+import sys
 
 import getopt
-from delete import Delete
-from alloc import Alloc
+from tpexe.action.delete import Delete
+from tpexe.action.alloc import Alloc
 
-CSV_PATH = 'teleport.csv'
+CSV_PATH = './teleport.csv'
 
 def main(argv):
     try:
-        opts, args = getopt.getopt(argv,"hda")
+        opts, args = getopt.getopt(argv, "hda")
     except getopt.GetoptError:
         print('Usage: run.py -d [-a]')
         sys.exit(2)
@@ -20,9 +20,9 @@ def main(argv):
         if opt == '-h':
             print('Usage: run.py -d [-a]')
             sys.exit()
-        elif opt in ("-a"):
+        elif opt in "-a":
             alloc.alloc_run() 
-        elif opt in ("-d"):
+        elif opt in "-d":
             delete.delete_host_run()
 
 if __name__ == "__main__":
