@@ -1,7 +1,7 @@
-import os, sys
+import os
+import sys
 import yaml
 
-CONF = os.getcwd() + '/../../config.yaml'
 class GetConfig(object):
 
     def __init__(self, conf):
