@@ -1,5 +1,6 @@
-import os, sys
 
+import os
+import sys
 import requests
 import json
 import pyotp
